@@ -1,4 +1,4 @@
-# $Id: HTTP.pm,v 1.45 2003/11/22 06:02:39 rcaputo Exp $
+# $Id: HTTP.pm,v 1.48 2004/01/14 19:21:53 rcaputo Exp $
 # License and documentation are after __END__.
 
 package POE::Component::Client::HTTP;
@@ -9,7 +9,7 @@ sub DEBUG      () { 0 }
 sub DEBUG_DATA () { 0 }
 
 use vars qw($VERSION);
-$VERSION = '0.59';
+$VERSION = '0.60';
 
 use Carp qw(croak);
 use POSIX;
@@ -691,7 +691,10 @@ sub poco_weeble_io_flushed {
 
   my $request = $heap->{request}->{$request_id};
   $request->[REQ_STATE] = RS_IN_STATUS;
-  $request->[REQ_WHEEL]->shutdown_output();
+  # XXX - Removed a second time.  The first time was in version 0.53,
+  # because the EOF generated by shutdown_output() causes some servers
+  # to disconnect rather than send their responses.
+  # $request->[REQ_WHEEL]->shutdown_output();
 }
 
 #------------------------------------------------------------------------------
@@ -779,7 +782,7 @@ sub poco_weeble_io_read {
     # bogus headers in the content?
     if (
       $request->[REQ_BUFFER] =~
-      s/^(HTTP\/[0-9\.]+)?\s*(\d+)\s*(.*?)([\x0D\x0A]+)([^\x0D\x0A])/$5/
+      s/^([A-Z]+(?:\/[0-9\.]+)?)?\s*(\d+)\s*(.*?)([\x0D\x0A]+)([^\x0D\x0A])/$5/x
     ) {
       DEBUG and
         warn "wheel $wheel_id got a status line... moving to headers.\n";
